@@ -21,10 +21,11 @@
  */
 typedef struct {
     PyObject_HEAD
+    builder_t builder;
     PyObject *target_send;
-    builder_t *builder;
     PyObject *prefix;
     PyObject *key;
+    int object_depth;
 } KVItemsBasecoro;
 
 /**
